#
# spec file for package rear
#
# Copyright (c) 2015 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%bcond_without	use_mkisofs

Name:           rear
Version:        1.17.2
Release:        3.5
Summary:        Relax-and-Recover (abbreviated rear) is a Linux Disaster Recovery framework
License:        GPL-2.0+
Group:          Productivity/Archiving/Backup
Url:            http://relax-and-recover.org/
# as GitHub stopped with download section we need to go back to Sourceforge for downloads
Source0:        http://sourceforge.net/projects/rear/files/rear/1.17/%{version}/rear-%{version}.tar.gz
# Source11 SLE11-ext3-example.conf is a working example for SLE11 with default ext3 filesystem
# that gets installed as /usr/share/rear/conf/SLE11-ext3-example.conf
Source11:       SLE11-ext3-example.conf
# Source12 SLE12-btrfs-example.conf is a working example for SLE12 with default btrfs subvolumes
# that gets installed as /usr/share/rear/conf/SLE12-btrfs-example.conf
Source12:       SLE12-btrfs-example.conf
# Source99 rear-rpmlintrc filters false positives rpmlint warning messages, see
# https://en.opensuse.org/openSUSE:Packaging_checks#Building_Packages_despite_of_errors
Source99:       rear-rpmlintrc
# rear contains only bash scripts plus documentation so that on first glance it could be "BuildArch: noarch"
# but actually it is not "noarch" because it only works on those architectures that are explicitly supported.
# Of course the rear bash scripts can be installed on any architecture just as any binaries can be installed on any architecture.
# But the meaning of architecture dependent packages should be on what architectures they will work.
# Therefore only those architectures that are actually supported are explicitly listed.
# This avoids that rear can be "just installed" on architectures that are actually not supported (e.g. ARM or IBM z Systems):
ExclusiveArch:  %ix86 x86_64 ppc ppc64 ppc64le
# Furthermore for some architectures it requires architecture dependent packages (like syslinux for x86 and x86_64)
# so that rear must be architecture dependent because ifarch conditions never match in case of "BuildArch: noarch"
# see the GitHub issue https://github.com/rear/rear/issues/629
%ifarch %ix86 x86_64
Requires:       syslinux
%endif
# In the end this should tell the user that rear is known to work only on x86 x86_64 ppc ppc64 ppc64le
# and on x86 x86_64 syslinux is explicitly required to make the bootable ISO image
# (in addition to the default installed bootloader grub2) while on ppc ppc64 ppc64le the
# default installed bootloader yaboot is also useed to make the bootable ISO image.
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
# LSB RPM Requires:
# Begin of "Requires: lsb" cleanup:
# Rear upstream has "Requires: lsb" but that requires much too much,
# see https://bugzilla.novell.com/show_bug.cgi?id=807747#c4
# "A distribution is LSB Certified or LSB compliant if and only if
#  the distribution provides all requirements as outlined in the
#  specification."
# Accordingly SUSE's lsb RPM requires tons of stuff that is not
# needed by Rear (in particular various graphical libraries,
# sound stuff, printing stuff, and so on).
# Therefore "Requires: lsb" is replaced by explicitly listing the RPM packages
# that are mandatory (in particular when a binary is called in a script) for Rear (as RPM Requires)
# plus what seems to be optional (nice to have) for Rear (as RPM Recommends)
# minus library packages because needed libraries should be automatically required.
# I <jsmeix@suse.de> think requiring RPM packages instead of binaries is better
# because it keeps the list shorter which is hopefully easier to maintain and
# the requirements are on a more higher level which is hopefully more unsusceptible against
# minor changes in what exact binaries names are actually called by Rear.
# To test if a binary is called by a Rear script the following was done (example for /usr/bin/bc):
#   BIN="bc"
#   for f in $( find /usr/share/rear/ )
#   do grep "\<$BIN\> " $f 2>/dev/null | grep -v '^[[:space:]]*#'
#   done
# What is not tested to find out if a binary is called by a Rear script is "eval" stuff,
# something like STRING=<result of whatever calls> ; eval $STRING
# Usually Rear calls "eval echo ..." or "eval "${EXTERNAL_whatever[@]}"
# except in /usr/share/rear/finalize/default/88_check_for_mount_by_id.sh that calls
#   eval "$(scsi_id ...
# where the only scsi_id that I could find is /usr/lib/udev/scsi_id
# which belongs to udev and I assume that udev is installed in any case
# so that there is no explicit RPM Requires for udev in Rear.
# What is also not tested to find out what Rear actually needs is
# which files (not only binaries) Rear needs to build up its recovery system
# (in particular tools for partitioning, creating filesystems, and bootloader installation).
# I assume what Rear needs to build up the system-specific recovery system is installed
# (e.g. if the ext4 filesystem is used, I assume mkfs.ext4 is installed)
# so that there are no explicit RPM Requires needed for that in Rear.
# The following list was derived from the RPM Requires of SUSE's lsb package
# (its last RPM changelog entry dated "Tue Oct  1 07:01:56 UTC 2013") as follows:
#   for r in $( grep ^Requires: lsb.spec | tr -s ' ' | cut -d ' ' -f2 )
#   do rpm -q --whatprovides $r
#   done | sort -u
# which results the following list where only what is needed for Rear is activated:
#   Mesa-9.2.3-61.9.1.i586
#   Mesa-libGL1-9.2.3-61.9.1.i586
#   at-3.1.13-5.4.1.i586
Requires:       bash
Requires:       bc
Requires:       binutils
Requires:       coreutils
Requires:       cpio
#   cronie-1.4.8-50.1.2.i586
#   cups-client-1.5.4-140.1.i586
Requires:       diffutils
#   ed-1.9-2.1.2.i586
Requires:       file
Requires:       findutils
#   fontconfig-2.11.0-1.1.i586
#   foomatic-filters-4.0.12-5.1.1.i586
Requires:       gawk
#   gettext-runtime-0.18.3.1-1.1.i586
#   ghostscript-9.10-45.4.i586
# Rear calls getent in /usr/share/rear/rescue/default/90_clone_users_and_groups.sh
Requires:       glibc
#   glibc-i18ndata-2.18-4.11.1.noarch
Requires:       grep
Requires:       gzip
#   libGLU1-9.0.0-7.1.2.i586
#   libXt6-1.1.4-2.1.2.i586
#   libXtst6-1.2.2-2.1.2.i586
#   libasound2-1.0.27.2-3.5.1.i586
#   libatk-1_0-0-2.10.0-1.1.i586
#   libglib-2_0-0-2.38.2-8.2.i586
#   libgtk-2_0-0-2.24.22-2.1.i586
#   libjpeg62-62.0.0-24.1.3.i586
#   libpango-1_0-0-1.36.1-4.2.i586
#   libpng12-0-1.2.50-6.1.2.i586
#   libqt4-4.8.5-5.6.1.i586
#   libqt4-sql-4.8.5-5.6.1.i586
#   libqt4-x11-4.8.5-5.6.1.i586
#   libxml2-tools-2.9.1-2.1.2.i586
# Rear calls "lsb_release" in /usr/share/rear/lib/config-functions.sh
Requires:       lsb-release
#   m4-1.4.16-14.1.2.i586
#   mailx-12.5-14.1.3.i586
#   make-3.82-160.2.1.i586
#   man-2.6.3-9.1.3.i586
#   mozilla-nss-3.15.3.1-8.1.i586
Requires:       net-tools
#   patch-2.7.1-4.1.2.i586
#   pax-3.4-155.1.2.i586
Requires:       perl-base
#   postfix-2.9.6-7.4.1.i586
Requires:       procps
#   psmisc-22.20-5.1.2.i586
#   python-2.7.5-8.3.1.i586
#   python3-3.3.2-5.1.3.i586
#   qt3-3.3.8c-128.1.2.i586
Requires:       rsync
Requires:       sed
#   shadow-4.1.5.1-8.1.2.i586
#   systemd-sysvinit-208-15.1.i586
#   sysvinit-tools-2.88+-89.1.2.i586
Requires:       tar
#   time-1.7-3.1.2.i586
Requires:       util-linux
#   xdg-utils-20121008-2.2.1.noarch
# End of "Requires: lsb" cleanup.
# Non-LSB RPM Requires:
# all RPM based systems seem to have this and call it the same
Requires:       ethtool
Requires:       iproute2
Requires:       iputils
%if 0%{?suse_version} >= 1230
Requires:       %{_sbindir}/agetty
%else
Requires:       /sbin/mingetty
%endif
%if %{with use_mkisofs}
Requires:       %{_bindir}/mkisofs
%else
Requires:       %{_bindir}/genisoimage
%endif
# recent SUSE versions have an extra nfs-client package
Requires:       nfs-client
# Rear calls openssl in /usr/share/rear/rescue/default/50_ssh.sh
Requires:       openssl
# openSUSE from 11.1 and SLES from 11 uses rpcbind instead of portmap
Requires:       rpcbind

%description
Relax-and-Recover (abbreviated rear) is a highly modular
disaster recovery framework for GNU/Linux based systems,
but can be easily extended to other UNIX alike systems.
The disaster recovery information (and maybe the backups)
can be stored via the network, local on hard disks or
USB devices, DVD/CD-R, tape, etc. The result is also a
bootable image that is capable of booting via PXE,
DVD/CD and USB media.

Relax-and-Recover integrates with other backup software
and provides integrated bare metal disaster recovery
abilities to the compatible backup software.

Warning for users who like to upgrade Relax-and-Recover:
Users who already use it must re-validate that their
particular disaster recovery procedure still works.
See in particular "Version upgrades" at
http://en.opensuse.org/SDB:Disaster_Recovery

Additionally when you already use Relax-and-Recover and
you upgrade software that is related to the basic system
(e.g. kernel, storage, bootloader, init, networking) or
you do other changes in your basic system, you must also
re-validate that your particular disaster recovery
procedure still works for you.

%prep
%setup -q -n rear-%{version}
# add a specific os.conf to not depend on LSB dependencies
# (otherwise it calls "lsb_release" in /usr/share/rear/lib/config-functions.sh)
# for the suse_version values see the listing at
# http://en.opensuse.org/openSUSE:Build_Service_cross_distribution_howto
# in particular see there the "Note" that reads
# "sles_version is no longer set in SLES 11. Use suse_version == 1110 instead.":
%if 0%{?suse_version} == 1110
# SLE 11
OS_VERSION="11"
%endif
%if 0%{?suse_version} == 1140
# openSUSE 11.4
OS_VERSION="11.4"
%endif
%if 0%{?suse_version} == 1210
# openSUSE 12.1
OS_VERSION="12.1"
%endif
%if 0%{?suse_version} == 1220
# openSUSE 12.2
OS_VERSION="12.2"
%endif
%if 0%{?suse_version} == 1230
# openSUSE 12.3
OS_VERSION="12.3"
%endif
%if 0%{?suse_version} == 1310
# openSUSE 13.1
OS_VERSION="13.1"
%endif
%if 0%{?suse_version} == 1315
# SLE 12
OS_VERSION="12"
%endif
%if 0%{?suse_version} == 1320
# openSUSE 13.2
OS_VERSION="13.2"
%endif
echo -e "OS_VENDOR=SUSE_LINUX\nOS_VERSION=$OS_VERSION" >etc/rear/os.conf

%build
# no code to compile - all bash scripts - but at least run "make validate"
# that runs "bash -n" for all bash files to test if the plain syntax is o.k.
make validate

%install
make install DESTDIR="%{buildroot}"
# Source11 SLE11-ext3-example.conf is a working example for SLE11 with default ext3 filesystem
# that gets installed as /usr/share/rear/conf/SLE11-ext3-example.conf
install -m 644 %{SOURCE11} %{buildroot}%{_datadir}/rear/conf/SLE11-ext3-example.conf
# Source12 SLE12-btrfs-example.conf is a working example for SLE12 with default btrfs subvolumes
# that gets installed as /usr/share/rear/conf/SLE12-btrfs-example.conf
install -m 644 %{SOURCE12} %{buildroot}%{_datadir}/rear/conf/SLE12-btrfs-example.conf

%files
%defattr(-,root,root,-)
%doc AUTHORS COPYING README.adoc doc/*.txt doc/*.adoc doc/user-guide/*.adoc doc/mappings/
%{_mandir}/man8/rear.8*
%config(noreplace) %{_sysconfdir}/rear/
%config(noreplace) %{_datadir}/rear/
%{_localstatedir}/lib/rear/
%{_sbindir}/rear

%changelog
* Mon Sep  7 2015 jsmeix@suse.de
- Update to version 1.17.2
  * Fixed the NTP startup script (issue #641)
  * Fixed the vfat label issue (issue #647)
  * Improved the DUPLICITY method with finding all required
    libraries and python scripts
  * Added the /run directory to the list of recreating missing
    directories (issue #619)
  * Fix issue with USB disk and rsync as internal backup
    program (issue #645)
  * Fix rsync restore: -anchored invalid rsync option (issue #642)
  * A new variable was introduced NSR_POOLNAME (issue #640)
  * Replaced almost all temporary files from /tmp/ to $TMP_DIR/
    (issue #607)
    Related to security recommendations for Fedora and RHEL:
    https://bugzilla.redhat.com/show_bug.cgi?id=1239009 (f22)
    https://bugzilla.redhat.com/show_bug.cgi?id=1238843 (rhel 7.2)
  * In script 27_hpraid_layout.sh added the missing
    HPSSACLI_BIN_INSTALLATION_DIR variable to the COPY_AS_IS
    array (issue #630)
  * Syslinux version > 5.00 is now supported (ISO and USB output)
    works on Debian 8, Ubuntu 15.04 (issue #624)
  * Bail out when syslinux/modules are not found in lib/
    bootloader-functions.sh (issues #467 and #596)
    You could also define a variable SYSLINUX_MODULES_DIR if rear
    cannot find it automatically (should not be necessary)
  * Support was added for SLES11 on PPC64 hardware
    (issues #616 and #628)
  * Support was added for new hardware - PPC64LE - RHEL
    and Ubuntu (issue # 627)
  * FIX the hashed password (SSH_ROOT_PASSWORD variable) and
    added a missing library libfreeblpriv3 (issue #560)
  * Insert a 3 seconds sleep after a volume group restauration
    to give udevd or systemd-udevd time to create needed devices
    (issue #608 and #617)
  * Variable MANUAL_INCLUDE=YES has been introduced to work with
    array BACKUP_PROG_INCLUDE (issue #597)
  * Add new variable NSR_DEFAULT_POOL_NAME (defaulting to Default)
    to use a different default pool name.
    Renamed the RETENTION_TIME variable to NSR_RETENTION_TIME
    (issue #640)
  * new document 10-integrating-external-backup.adoc which
    explains the steps to take for a new backup integration
    into rear
  * All AsciiDoc documentation changed extention
    from .txt to .adoc
- Known restrictions on openSUSE and SUSE Linux Enterprise
  (in general see https://en.opensuse.org/SDB:Disaster_Recovery):
  * rear 1.17.2 will not work with default btrfs on SLES12-SP1
    because support for btrfs in rear explicitly excludes
    snapshot subvolumes but on SLES12-SP1 what is mounted
    at '/' will be a btrfs snapshot subvolume (issue #556)
  * rear 1.17.2 does not work with UEFI because of various
    different reasons (issues #588 #585 #583 #229 #214)
  * rear does not support partitions of type 'gpt_sync_mbr'
    aka. 'hybrid (synced) MBR' (issue #544)
* Thu Sep  3 2015 jsmeix@suse.de
- Use "ExclusiveArch: %%ix86 x86_64 ppc ppc64 ppc64le" instead
  of "BuildArch: noarch" in the spec file.
  rear contains only bash scripts plus documentation so that
  on first glance it could be "BuildArch: noarch" but actually
  it is not "noarch" because it only works on those architectures
  that are explicitly supported. Of course the rear bash scripts
  can be installed on any architecture just as any binaries can be
  installed on any architecture. But the meaning of architecture
  dependent packages should be on what architectures they will
  work. Therefore only those architectures that are actually
  supported are explicitly listed. This avoids that rear can
  be "just installed" on architectures that are actually
  not supported (e.g. ARM or IBM z Systems).
  Furthermore for some architectures it requires architecture
  dependent packages (like syslinux for x86 and x86_64)
  so that rear must be architecture dependent.
  See the GitHub issue https://github.com/rear/rear/issues/629
* Tue Jun 30 2015 jsmeix@suse.de
- Update to version 1.17.1
  * Removed the plain password in the logs (and output) coming
    from BACKUP_PROG_CRYPT_KEY to avoid crib (issue #568)
  * Mount vfat file system without special mount options
    seems to work much better then with these options in recovery
    mode, therefore, we do not use these anymore (especially
    for /boot/efi) (issue #576)
  * Elilo support has been added for SLES
    (not fully tested yet) - issue #583
  * Grub2 rescue menu has been added (enable this feature
    with GRUB_RESCUE=y) - issue #589
  * splitted script 31_include_uefi_tools.sh in two pieces:
    31_include_uefi_tools.sh: to grab the UEFI tools (as long
    as /boot/efi is mounted), and 32_include_uefi_env.sh: to dig
    deeper into the configuration when UEFI is active
    (related to issue #214). This is necessary to have to UEFI
    tools on SLES 11/12 where we cannot create an UEFI bootable
    ISO image. We must boot in BIOS mode, and need the UEFI tools
    to make the system bootable over UEFI.
  * It is now possible to format an USB disk with a vfat and ext3
    partition (for UEFI booting) - issue #593
    rear -v format -- --efi /dev/<usbdevice>
    However, UEFI booting from an USB disk has not been
    implemented yet (sponsoring?).
  * Simplified the code for ext* fs and added StopIfError calls
    to prevent divide by zero during recovery (issue #598)
  * Syslinux version >6 requires some special handling due to
    splitting up the package (Ubuntu 15.04) (issue #584)
  * Debian 8 support added with ISO booting with latest syslinux
    release as well (issues #596, #599 and #600)
  * Changed the behavior of SSH_ROOT_PASSWORD - now saved as MD5
    hash password, but backwards compatibility is still respected
    (issue #560)
  * For EMC NetWorker server/client we added some exclude items
    to COPY_AS_IS_EXCLUDE_NSR (issue #571)
  * Removed the Warning message from main rear script as it was
    misleading (issues #563 and #564)
  * output/ISO/Linux-i386/80_create_isofs.sh: make sure
    ISO_FILES[@] are copied to isofs directory (issue #569)
- SLE11-ext3-example.conf is an example for SLE11
  with default ext3 filesystem that gets installed as
  /usr/share/rear/conf/SLE11-ext3-example.conf
- SLE12-btrfs-example.conf is an example for SLE12
  with default btrfs subvolumes that gets installed
  as /usr/share/rear/conf/SLE12-btrfs-example.conf
- Have config(noreplace) also for all files in /usr/share/rear/
  to avoid that RPM package update overwrites user edited files
  because Relax-and-Recover (rear) is meant to be adapted and
  enhanced by the user according to his particular needs
  (see http://en.opensuse.org/SDB:Disaster_Recovery).
- Added rear-rpmlintrc to filter the following false positives
  rpmlint warning messages:
  * non-etc-or-var-file-marked-as-conffile
    because config(noreplace) is intentionally for all files
    in /usr/share/rear/ (see above)
  * systemd-service-without-service_del_preun
    systemd-service-without-service_del_postun
    systemd-service-without-service_add_pre
    systemd-service-without-service_add_post
    because the systemd unit files in /usr/share/rear/skel/
    are not meant to be used in the running system.
    They are used to build the rear recovery system ISO image.
* Sun Mar 15 2015 p.drouand@gmail.com
- Update to version 1.17.0
  * rear 1.17 introduced a new stage directory (init) which
    is called before any workflow. Can be used for extra
    initialization code, custom configurations and other stuff
    that should happen each time that ReaR is used (was added
    especially for DRLM as plugin for their DRLM variables)
    (issue #557)
  * RHEL 5 could not mount NFS share as portmap daemon was not
    started yet. Reason was that script
    verify/NETFS/default/08_start_required_daemons.sh
    was executed after the mount test instead of before.
    (issue #547)
  * RHEL 6 on PPC64 architecture has problems with seclabel mount
    option. There was a fix which cuts the seclabel mount option
    (as rear is by default not using SELinux) (issue #545)
  * Disaster Recovery Linux Manager (DRLM) is a new Open Source
    project to centrally manage Disaster Recovery for Linux.
    ReaR 1.17 adds support for DRLM with a new configuration
    option DRLM_MANAGED=y (issue #522)
  * Adding /etc/crypto-policies/ when openssl is requested
    (prep/NETFS/default/09_check_encrypted_backup.sh) - required
    for https://bugzilla.redhat.com/show_bug.cgi?id=1179239
    (issue #523)
  * Introduced USING_UEFI_BOOTLOADER in default.conf file and
    modified all the involved scripts to follow the logic
    (issue #214)
  * Archicture PPC64 has been enhanced (partition recognition
    issue #536, console #537)
  * TSM restore filespace has been enhanced (issue #535)
  * Correct the usage of set -e and StopIfError function
    (issue #534, #541)
  * With BACKUP_TYPE=incremental disable variable
    NETFS_KEEP_OLD_BACKUP_COPY (mutual exclusive with this mode)
    (issue #143)
  * Increased to start variable from 32768 to 2097152 in script
    10_include_partition_code.sh (issue #492)
  * Adding /run/resolvconf/resolv.conf (Ubuntu) to rear image
    when found (issue #520)
  * When using /etc/rear/mappings/ip_addresses IPADDR/cidr
    must be translated into IPADDR and NETMASK (for RHEL 5 and 6)
    (issue #460)
  * mdadm layout code was changed in RHEL 7; code to deal with it
    (issue #518)
  * Adding missing driver xhci_hcd to GNU/Linux.conf (issue #519)
  * Adding findmnt command to GNU/Linux.conf file; request
    from https://bugzilla.opensuse.org/show_bug.cgi?id=908854
  * BTRFS code has been rewritten by J. Meixner to get
    SUSE rear116 fork back into our master tree of rear. BTRFS is
    now properly recreated on Fedora 20 and 21 and on SLES 12 and
    openSUSE 13 (issue #233, #497, #538) See also
    https://bugzilla.opensuse.org/show_bug.cgi?id=908854
  * Enhanced the systemd start-up of udev daemons which is
    different on Fedora 20 and 21 (issue #507, #531)
  * BACKUP_PROG_OPTIONS="anchored" became a default option
    in default.conf (issue #475)
  * Fixed an issue with auto-detection of the client name
    in BAREOS (issue #542)
  * Ubuntu 14.04 did not detect /dev/sda automatically - added
    upstart script 99-makedev.sh to create missing block devices
    like sda (issue #446)
  * New script
    usr/share/rear/layout/save/GNU/Linux/34_false_blacklisted.sh
    added as work-around. Sometimes we might see the HP Smart
    Storage Array disk listed as a multipath device. Most likely
    this device was not blacklisted in the blacklist section of
    the /etc/multipath.conf file (do not forget to rebuilt the
    initial ramdisk after this) e.g.
    falsempathdev=$( multipath -l | grep "HP,LOGICAL" | awk '{print $1}' )
    [#] mpatha
  * Added a systemd service script for SEP Sesam to start sesam
    client automatically (issue #498)
  * Disk Layout Generation with HP SmartArray with more than
    one Logical Drive correction introduced by issue #208
    (issue #455)
  * OUTPUT_URL=null was added to avoid 2 ISO images on the local
    system (issue #501, #419)
  * Fix drbd restore code so it can handle multiple volumes in
    single resource (issue #495)
  * Function get_device_name was enhanced to properly translate
    /dev/vg/lv to /dev/mapper/vg-lv (issue #494)
  * Fixed the "lvm wait yes" problem (issue #493)
  * Device name conflict when grep disklayout file without proper
    space (issue #491)
  * Several fixes with mdadm code
    (issue #480, #489, #490, #508, #539)
  * Several fixes in the 10_include_partition_code.sh script
    (issue #487, #492)
  * Being a bit more careful when deleting the outputfs directory
    when rear finishes (issue #465)
  * Add a new config option USE_STATIC_NETWORKING (issue #488)
  * Resolving library search with duply (issue #482)
  * Improved the RPM package build for SLES, removed
    the lsb requirement (issue #479)
  * Integrated the patch skip_sysconfig_kernel_if_not_exist.diff
    from SUSE (issue #477)
  * Debian 7 reference to grub.conf was corrected (issue #473)
  * Debian packing was improved (issue #474, #484)
  * Commercial backup solution Galaxy 10 support added to rear
    (issue #471)
    Also, point in time recovery was implemented (issue #472)
  * Fixed the error "unary operator expected with BACKUP_TYPE"
    (issue #422)
  * lvm release 2.02.72 had already the knowledge
    of norestorefile (issue #462)
  * Add prefix $OUTPUT_PREFIX to all PXE related files
    (issue #464)
  * 55-migrate-network-devices.sh: fixed type with /sys/class/net
    (issue #459)
  * Removed Get_Start_Date function with Netbackup because
    (depending on backup strategy) it led to partial restore
    only (issue #456)
  * 26_crypt_layout.sh: fixed issue when cypher contains :
    (issue #425)
  * 55-migrate-network-devices.sh: rebuild the array instead
    of unset (issue #452)
  * skel/default/etc/scripts/system-setup : change uname -n
    by $HOSTNAME to avoid short/long hostname problems
    (issue #439)
  * Added a mkdir for $VAR_DIR/output if dir does not exist
    (issue #440)
  * 95_check_missing_programs.sh to find REQUIRED_PROGS before
    proceeding (issue #418)
  * Added a fix for autorizing and recognizong the boot flag
    in the partition (issue #443)
  * udev showing error message during startup (issue #442)
  * Prevent "ntpd -q" from waiting forever if, for example,
    no network is available, by killing it after 10 seconds
    (issue #438)
  * Several improvements around duply and duplicity
    [Debian related] (issues #426, #478)
  * 95_copy_result_files.sh uses now [*] instead of [@] with
    array (issue #431)
  * New variable introduced for TSM in default.conf file
    called LANG_RECOVER (issue #424)
  * Added Pre check script for removing older releases first
    during upgrade (RPM - issue #361)
  * Prevent udev rule rewrites if systemd-udevd is running
    issue #405
  * Fix "Networker backup fails if pool name contains spaces"
    (issue #427 and #429)
  * Fix the "More than 128 partitions is not supported" problem
    (issue #373 and #428) during recreating the partition layout
  * A new configuration option, USE_STATIC_NETWORKING=y, will
    cause statically configured network settings to be applied
    even when USE_DHCLIENT is in effect (issue #447).
- Remove rear-release-notes.txt-1.16; rear-release-notes.txt has
  been updated
- Remove traditional_style_for_bash_3.diff; merged on upstream
  release
* Tue May 13 2014 jsmeix@suse.de
- Provide also the other documentation ("make install" only
  installs the man page).
* Fri May  9 2014 jsmeix@suse.de
- Version upgrade to 1.16 from upstream (fate#316508)
  that has in particular VLAN tagging support (fate#317032).
  For details see the rear-release-notes.txt file.
  Warning for users who upgrade Relax-and-Recover (rear):
  Users who already use it must re-validate that their
  particular disaster recovery procedure still works.
  See in particular "Version upgrades" at
  http://en.opensuse.org/SDB:Disaster_Recovery
- bug-859436_40_restore_with_tsm.sh.diff is obsolete
  because the issue is fixed in the uptream sources.
- rear-release-notes.txt-1.16 replaces the outdated
  doc/rear-release-notes.txt from rear-1.16.tar.gz.
- traditional_style_for_bash_3.diff replaces bash 4.x syntax
  with traditional style for bash 3.x if bash 3.x is used
  (i.e. up to openSUSE:11.1 and SLE11 where we have bash 3.x)
  where the test in the build environment assumes that the
  same bash major version is also used by the end-user in his
  runtime environment but even if the end-user had upgraded
  his bash it should not matter because bash 3.x syntax
  should also work for bash 4.x.
- Added an explicit os.conf to not depend on LSB dependencies
  to avoid calling "lsb_release" in config-functions.sh
  that might result inconsistent values (bnc#877042).
* Fri Feb  7 2014 jsmeix@suse.de
- Added "Requires: lsb-release" because rear calls "lsb_release"
  in /usr/share/rear/lib/config-functions.sh (bnc#861871).
* Fri Feb  7 2014 jsmeix@suse.de
- Cleanup of the LSB RPM requirements (bnc#861871):
  Replaced "Requires: lsb" by explicitly requiring
  only those RPM packages that are mandatory for rear
  (in particular when a binary is called in a script)
  because "Requires: lsb" would require much too much,
  see https://bugzilla.novell.com/show_bug.cgi?id=807747#c4
  "A distribution is LSB Certified or LSB compliant if and only if
  the distribution provides all requirements as outlined in the
  specification."
  Accordingly the lsb RPM requires tons of stuff that is not
  needed by rear (in particular various graphical libraries,
  sound stuff, printing stuff, and so on).
- Replaced rear-1.15.tar.gz with the current one from upstream at
  https://sourceforge.net/projects/rear/files/rear/1.15/rear-1.15.tar.gz
  that contains exactly same files but the tarball differs
  (probably it was re-packed at upstream) and that causes
  failures of our automated factory-auto check scripts like:
  "download_files is configured to fail when the upstream file
  is different then the committed file".
* Wed Jan 22 2014 jsmeix@suse.de
- Version upgrade to 1.15 from upstream (fate#316508).
  For details see the rear-release-notes.txt file.
- bug-859436_40_restore_with_tsm.sh.diff fixes recovery
  with TSM (Tivoli Storage Manager) since version 6.4 that
  results in an error message "ANS1102E" as fixed upstream
  in https://github.com/rear/rear/issues/356 (bnc#859436).
- Warning for users who upgrade from rear 1.10.0
  (e.g. when upgrading from SUSE Linux Enterprise 11):
  Rear 1.15 has many new features and fundamental changes.
  In particular the filesystem creation is totally different
  (via the so called "layout workflow" instead of the old
  "dr workflow" that has been removed in rear 1.14).
  Users who already use rear must completely re-validate that
  their particular disaster recovery procedure still works.
  See in particular "Version upgrades" at
  http://en.opensuse.org/SDB:Disaster_Recovery
* Wed Jun 12 2013 werner@suse.com
- Require /usr/bin/mkisofs instead of mkisofs
- The default getty is agetty now
* Wed Jun  5 2013 jengelh@inai.de
- Require mkisofs instead of genisoimage, as we plan to switch to
  it. (rear works both /usr/bin/mkisofs and /usr/bin/genisoimage)
- Avoid UUOC: better deletion strategy for gitignore
* Sun Feb 10 2013 p.drouand@gmail.com
- updated to rear 1.14 from upstream
  * see rear-release-notes.txt for more informations
- clean and rebase specfile
- remove debian files
- don't include manfiles and makefile in documentation
* Sun Feb 20 2011 schlomo.schapiro@novell.com
- updated to rear 1.10.0 from upstream
  * remove symlinks that conflict with directories to resolve
    RPM upgrade problems
  * add OS_MASTER_* variables to define a parent distro,
    e.g. Fedora for CentOS
  * remove Linux-x86_64 and map it to Linux-i386 to remove
    a lot of symlinks pointing to directories
  * bugfixes for tape blocksize and bootable USB media
* Mon Feb 14 2011 schlomo.schapiro@novell.com
- updated to rear 1.9.0 from upstream
  * many bugfixes
  * (new) P2V/V2V/V2P/P2P with system reconfiguration
  * (new) support Data Protector, Bacula, OBDR, Tapes
  * (new) use udev for module loading, support firmware loading
  * see full list of changes at
    http://rear.svn.sourceforge.net/viewvc/rear/releases/1.9.0/usr/share/rear/CHANGES
* Fri Dec 11 2009 schlomo.schapiro@novell.com
- updated to rear 1.7.23 from upstream
  * some bugfixing
  * added validation info for openSUSE 11.2 i386 and x86_64
  * improved library collection for 64bit Linux
    (e.g. /lib*/libnss*)
  * symlink doc and contrib in the dist archive
    to reduce the size
  * clone required system users/groups to rescue system
    (daemon and rpc)
* Wed Dec  2 2009 schlomo.schapiro@novell.com
- updated to rear 1.7.22 from upsteam
  * added -L to stat call to read real device in
    29_find_required_devices.sh
  * make svn2host report scp errors
  * updated rear.spec, rear.sourcespec of SUSE and FEDORA
  * updated contrib/mkvendorrp to pull version nr from
    rear, CHANGED
  * updated lib/spec/Fedora/rear.sourcespec Require field
    and doc/
  * updated skel/default/etc/scripts/system-setup to improve
    loading modules
  * updated finalize/default/88_check_for_mount_by_id.sh
  * added prep/GNU/Linux/28_include_vmware_tools.sh
  * moved some misplaced scripts from pack to build
  * added contrib/svn2hosts (continuous integration script)
  * fixed up mkdist-workflow.sh and contrib/svn2tar to share
    more code
  * removed the UTF-8 conversion
    (IMHO should be only done manually)
  * removed the overwriting of the generic spec file
    with vendor specific spec file
  * fixed the copying of /dev/shm/* by adding it to
    COPY_AS_IS_EXCLUDE
  * support open-vm-tools and loading of vmxnet
  * removed the usage of udev_volume_id (for RHEL4) in favour
    of internal vol_id
  * fixed internal vol_id to correctly strip leading spaces
    from the values
  * fixed 31_create_filesystems.sh to actually correctly
    create ext* and support FS labels with < or > in them
    (https://sourceforge.net/tracker/?func=detail&aid=2891970&group_id=171835&atid=859452)
  * added usleep and mktemp
  * Fixed all wrong occurences of [*] with [@].
    See https://sourceforge.net/tracker/?func=detail&atid=859452&aid=2877091&group_id=171835
  * backup/NETFS/default/40_create_include_exclude_files.sh
    fixed variable name for excluded mountpoints to actually
    read EXCLUDE_MOUNTPOINTS
  * recreate/GNU/Linux/22_create_lvm2_devices.sh
    move lvm vgchange -a y  in loop to avoid old VGs to activate
* Sun Sep 27 2009 schlomo.schapiro@novell.com
- updated to rear 1.7.21 from upstream
  * support openSUSE 11.2 (M6)
  * rsyslogd
  * ext4
* Sun Mar  8 2009 Schlomo.Schapiro@novell.com
- import into Factory
* Thu Jan 29 2009 Schlomo Schapiro <rear@schlomo.schapiro.org>
- 1.7.14-1
- added man page
- fixed TSM bug with result files
- patch rear binary to point to correct _datadir and _sysconfdir
- move distribution config files to /usr/share/rear/conf
- add hpacucli support
- TSM point-in-time restore
- fix bonding for multiple bonding devices
* Tue Jan 20 2009 Gratien D'haese <gdha@sourceforge.net>
- 1.7.13-1
- add COPYING license file
- linux-functions.sh: added rpmtopdir function;
- mkdist-workflow.sh: updated with rpmtopdir function; convert
  doc files to UTF-8
* Fri Jan  9 2009 Gratien D'haese <gdha@sourceforge.net>
- 1.7.12-1
- NetBackup integration completed
- moved validation from /etc/rear to doc directory
* Tue Dec 30 2008 Gratien D'haese <gdha@sourceforge.net>
- 1.7.11-1
- added scriptfor Data Protector and NetBackup integration
* Wed Dec 17 2008 Gratien D'haese <gdha@sourceforge.net>
- 1.7.10-1
- completed verify/NBU/default/40_verify_nbu.sh script for NBU
- remove contrib entry from %%%%doc line in spec file
* Mon Dec  1 2008 Gratien D'haese <gdha@sourceforge.net>
- 1.7.9-1
- remove from skel/default the symbolic links sh->bash,
  bin/init->init and the empty files etc/mtab, var/log/lastlog
  and var/lib/nfs/state
- add the link sh-bash into file
  pack/GNU/Linux/00_create_symlinks.sh
- add new file pack/GNU/Linux/10_touch_empty_files.sh
  to create the empty files
- add pack/GNU/Linux/20_create_dotfiles.sh and removed
  .bash_history from skel/default
- Added intial scripts for rear integration with NetBackup
  (of Symantec)
- copy rear.sourcespec according OS_VENDOR
- correct rear.spec file according comment 11 of bugzilla #468189
* Mon Oct 27 2008 Gratien D'haese <gdha@sourceforge.net>
- 1.7.8-1
- Fix rpmlint error/warnings for Fedora packaging
- updated the Summary line and %%%%install section
* Fri Oct 24 2008 Gratien D'haese <gdha@sourceforge.net>
- 1.7.7-1
- rewrote rear.spec for Fedora Packaging request
* Mon Aug 28 2006 Schlomo Schapiro <rear@schlomo.schapiro.org>
- 1.0-1
- Initial RPM Release
